# GridCal
# Copyright (C) 2015 - 2024 Santiago Peñate Vera
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 3 of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
from GridCalEngine.Simulations.options_template import OptionsTemplate


class ClusteringAnalysisOptions(OptionsTemplate):

    def __init__(self, n_points: int):
        """
        Clustering options
        :param n_points: number of points
        """
        OptionsTemplate.__init__(self, name='Clustering analysis options')

        self.n_points = n_points

        self.register(key="n_points", tpe=int)
